
import { Component, OnInit, ViewChild  } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Boilerplate } from 'src/app/models/boilerplate.model';
import { Sections } from 'src/app/models/boilerplate.model';
import { BoilerplateService } from 'src/app/services/boilerplate.service';
import { MainService } from 'src/app/services/main.service';
import {MainDetailsComponent} from 'src/app/components/main-details/main-details.component'
import {PrefixDetailsComponent} from 'src/app/components/prefix-details/prefix-details.component'
import {SuffixDetailsComponent} from 'src/app/components/suffix-details/suffix-details.component'
import { NotifierService } from "angular-notifier";



@Component({
  selector: 'app-boilerplate-details',
  templateUrl: './boilerplate-details.component.html',
  styleUrls: ['./boilerplate-details.component.scss']
})
export class BoilerplateDetailsComponent implements OnInit {
  panelOpenState = false;

  subjects:string[] = [];
  
  systems?: Sections [];

  currentboilerplate: Boilerplate = {
    has_prefix: false,
    has_main: false,
    has_suffix: false
  };


  message = '';
  searchText = '';
  searchTextinstances = '';
  private readonly notifier: NotifierService;

  constructor(
    private mainService: MainService,
    private boilerplateService: BoilerplateService,
    private route: ActivatedRoute,
    notifierService: NotifierService,
    private router: Router) { this.notifier = notifierService; }

  @ViewChild(MainDetailsComponent) mainchild!: MainDetailsComponent;
  @ViewChild(PrefixDetailsComponent) prefchild!: PrefixDetailsComponent;
  @ViewChild(SuffixDetailsComponent) sufchild!: SuffixDetailsComponent;

  ngOnInit(): void {
    this.message = '';
    this.getchoices(); 
    this.getBoilerplate(this.route.snapshot.params.gb, this.route.snapshot.params.id);
  }


  getBoilerplate(gb:any, id: number): void {
    this.boilerplateService.get(gb, id)
      .subscribe(
        data => {
          this.currentboilerplate = data;
          console.log(data);
        },
        error => {
          console.log(error);
        });
  }

  updateBoilerplate(): any {
    if (this.currentboilerplate.has_prefix){this.prefchild.updatePrefix()};
    if (this.currentboilerplate.has_main){this.mainchild.updateMain();};
    if (this.currentboilerplate.has_suffix){this.sufchild.updateSuffix();};

    this.boilerplateService.update(this.route.snapshot.params.gb, this.currentboilerplate.id, this.currentboilerplate)
      .subscribe(
        response => {
          this.notifier.notify("success",(JSON.stringify("Requirement " + this.currentboilerplate.title + " updated")));
          this.router.navigate(['/groupboilerplates/'+this.route.snapshot.params.gb+'/boilerplates']);
        },
        error => {
          this.notifier.notify("warning",(JSON.stringify(error)));
        });
  }

  deleteBoilerplate(): void {
    if(confirm("Αre you sure you want to delete this Boilerplate?")) {
      this.boilerplateService.delete(this.route.snapshot.params.gb, this.currentboilerplate.id)
        .subscribe(
          response => {
            console.log(response);
            this.router.navigate(['/groupboilerplates/'+ this.route.snapshot.params.gb +'/boilerplates']);
          },
          error => {
            console.log(error);
          });
      }
  }

  getchoices(): void{
    //System
    this.mainService.getdictionary()
      .subscribe(
        data => {
              this.systems = data
        },
        error => {
          console.log(error);
        });
  }
      
  checkeven(i:any): any {
    if (i%2 == 0){ return true}
    return false
  }

  checkthree(i:any): any {
    if (i%3 == 0){ return true}
    return false
  }

  checklen(i:any): any {
    if (i.length>1){ return true}
    return false
  }
}
